==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/Analytics/ServiceDataLakeStoreGen1.md <==
# ServiceDataLakeStoreGen1


```text
azure-4/Item/Analytics/ServiceDataLakeStoreGen1
```

```text
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')
```



| Illustration | ServiceDataLakeStoreGen1 | ServiceDataLakeStoreGen1Card | ServiceDataLakeStoreGen1Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1.png) | ![illustration for ServiceDataLakeStoreGen1](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1.Local.png) | ![illustration for ServiceDataLakeStoreGen1Card](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1Card.Local.png) | ![illustration for ServiceDataLakeStoreGen1Group](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1Group.Local.png) |




## ServiceDataLakeStoreGen1

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1('ServiceDataLakeStoreGen1', 'Service Data Lake Store Gen1', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1('ServiceDataLakeStoreGen1', 'Service Data Lake Store Gen1', 'an optional tech label')
@enduml
```

## ServiceDataLakeStoreGen1Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Card
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Card('ServiceDataLakeStoreGen1Card', 'Service Data Lake Store Gen1 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Card
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Card('ServiceDataLakeStoreGen1Card', 'Service Data Lake Store Gen1 Card', 'an optional description')
@enduml
```

## ServiceDataLakeStoreGen1Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Group
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Group('ServiceDataLakeStoreGen1Group', 'Service Data Lake Store Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Group
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Group('ServiceDataLakeStoreGen1Group', 'Service Data Lake Store Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/azure-4/Item/Analytics/ServiceDataLakeStoreGen1.md <==
# ServiceDataLakeStoreGen1


```text
azure-4/Item/Analytics/ServiceDataLakeStoreGen1
```

```text
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')
```



| Illustration | ServiceDataLakeStoreGen1 | ServiceDataLakeStoreGen1Card | ServiceDataLakeStoreGen1Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1.png) | ![illustration for ServiceDataLakeStoreGen1](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1.Local.png) | ![illustration for ServiceDataLakeStoreGen1Card](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1Card.Local.png) | ![illustration for ServiceDataLakeStoreGen1Group](../../../azure-4/Item/Analytics/ServiceDataLakeStoreGen1Group.Local.png) |




## ServiceDataLakeStoreGen1

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1('ServiceDataLakeStoreGen1', 'Service Data Lake Store Gen1', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1('ServiceDataLakeStoreGen1', 'Service Data Lake Store Gen1', 'an optional tech label')
@enduml
```

## ServiceDataLakeStoreGen1Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Card
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Card('ServiceDataLakeStoreGen1Card', 'Service Data Lake Store Gen1 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Card
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Card('ServiceDataLakeStoreGen1Card', 'Service Data Lake Store Gen1 Card', 'an optional description')
@enduml
```

## ServiceDataLakeStoreGen1Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Group
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Group('ServiceDataLakeStoreGen1Group', 'Service Data Lake Store Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStoreGen1Group
include('azure-4/Item/Analytics/ServiceDataLakeStoreGen1')

' renders the element
ServiceDataLakeStoreGen1Group('ServiceDataLakeStoreGen1Group', 'Service Data Lake Store Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
